<?php
/**
 * @package Typal2woo
 */

add_action( 'admin_init', 'typal2_theme_settings_init' );
add_action( 'admin_menu', 'typal2_add_settings_page' );

/*=SETUP----------------------------------------------------*/

function typal2_theme_settings_init(){
	register_setting( 'typal2_theme_settings', 'typal2_theme_settings', 'typal2_options_validate' );
}


function typal2_admin_enqueue_scripts( $hook_suffix ) {
	$template_directory_uri = get_template_directory_uri();

	wp_enqueue_style( 'typal2-theme-options', $template_directory_uri . '/theme-options/theme-options.css', false, '1.0.4' );
	wp_enqueue_script( 'typal2-theme-options', $template_directory_uri . '/theme-options/theme-options.js', array( 'jquery' ), '1.0.4' );
}

add_action( 'admin_print_styles-appearance_page_setting', 'typal2_admin_enqueue_scripts' );



function typal2_add_settings_page() {
add_theme_page( __( 'Theme Options', 'typal2' ), __( 'Theme Options', 'typal2' ), 'manage_options', 'setting', 'typal2_theme_settings_page');
}

/**
 * Options Page Build
 */

function typal2_theme_settings_page() {	
?>

<!--GO Page Options-->

<div class="wrap">

<?php
if ( isset ($_GET['settings-updated']) ) { ?>
<div id="message" class="updated fade -message"><p><?php _e('Options Saved','typal2'); ?></p></div>
<?php } ?>

<h2><?php $theme_name = wp_get_theme(); echo $theme_name ?><?php _e( ' Theme Options', 'typal2' ) ?></h2>


<form method="post" action="options.php">

<?php settings_fields( 'typal2_theme_settings' ); ?>
<?php $options = get_option( 'typal2_theme_settings' ); ?>

<table class="form-table">

<tr valign="top">
<th scope="row"><?php _e( 'Feature Page', 'typal2' ); ?></th>
<td>

<select id="typal2_theme_settings[feature_page]" name="typal2_theme_settings[feature_page]">
<?php
$args = array( 'sort_order' => 'ASC', 'sort_column' => 'post_title', 'post_status' => 'publish' );
$pages = get_pages( $args ); ?>
	<?php echo "<option value=''>"; ?><?php _e( 'None Feature Page', 'typal2' ); ?><?php echo "</option>"; ?>
        <?php foreach ( $pages as $page ) : ?>
<?php 
	$selected = ( $page->ID == $options['feature_page'] ) ? 'selected = "selected"' : '';
	echo "<option value='$page->ID' $selected>$page->post_title</option>";
?>
        <?php endforeach; ?>
</select>
<br />
<label class="description" for="typal2_theme_settings[feature_page]"><?php _e( 'Select the page, the contents of which will be shown on the homepage.','typal2'); ?></label>
</td>
</tr>

<tr valign="top">
<th scope="row"><?php _e( 'Custom Title Recent Posts', 'typal2' ); ?></th>
<td>
<input id="typal2_theme_settings[blogposts_title]" class="regular-text" type="text" size="36" name="typal2_theme_settings[blogposts_title]" value="<?php echo esc_attr($options['blogposts_title']); ?>" />
<br />
<label class="description" for="typal2_theme_settings[blogposts_title]"><?php _e( 'Enter your custom title recent blog posts.','typal2'); ?></label>
</td>
</tr>

<tr valign="top">
<th scope="row"><?php _e( 'Number of Blog Posts', 'typal2' ); ?></th>
<td>

<select id="typal2_theme_settings[num_posts]" name="typal2_theme_settings[num_posts]">
<?php
	$items = array("0", "4", "8", "12");
	foreach ($items as $item) {
		$selected = ( $options['num_posts'] === $item ) ? 'selected = "selected"' : '';
		echo "<option value='$item' $selected>$item</option>";
	}
?>
</select>
<br />
<label class="description" for="typal2_theme_settings[num_posts]"><?php _e( 'Number of Recent Blog Posts in HomePage','typal2'); ?></label>
</td>
</tr>

</table>

<p class="submit-changes">
<input type="submit" class="button-primary" value="<?php _e( 'Save Options', 'typal2' ); ?>" />
</p>
</form>
</div><!--//wrap -->

<!--END Page Options-->


<?php
}

/*=Sanitize----------------------------------------------------*/
/*------------------------------------------------------------------*/
function typal2_options_validate( $input ) {

	$output = $options = get_option( 'typal2_theme_settings' );

		$output['feature_page'] = wp_filter_nohtml_kses($input['feature_page']);
		$output['blogposts_title'] = wp_filter_nohtml_kses($input['blogposts_title']);
		$output['num_posts'] = wp_filter_nohtml_kses($input['num_posts']);

	return apply_filters( 'typal2_options_validate', $output, $input, $options );
}

?>